#include "glpanel.h"

GLPanel::GLPanel(QWidget *parent)
: QGLWidget(parent)
{
}

void
GLPanel::initializeGL()
{
    // set white as background color and clear window
    glClearColor(0.0f, 0.0f, 0.0f, 0.0f); 
    glClear(GL_COLOR_BUFFER_BIT);
}

void
GLPanel::resizeGL(int _width,
                  int _height)
{
    // store GL canvas sizes in object properties
    m_w = _width;
    m_h = _height;

    // setup the viewport to canvas dimensions
    glViewport(0, 0, (GLint)m_w, (GLint)m_h);

    // reset the coordinate system
    glMatrixMode(GL_PROJECTION); 
    glLoadIdentity();

    // establish the clipping volume by setting up an
    // orthographic projection
//     GLdouble left = -(GLdouble)m_w/2;
//     GLdouble right = (GLdouble)m_w/2;
//     GLdouble bottom = -(GLdouble)m_h/2;
//     GLdouble top = (GLdouble)m_h/2;
//     glOrtho(left, right, bottom, top, -1.0, 1.0);
    glOrtho(0.0,(GLdouble)m_w,0.0,(GLdouble)m_h, -1.0, 1.0);

    // setup display in model coordinates
    glMatrixMode(GL_MODELVIEW); 
    glLoadIdentity();
}

void
GLPanel::paintGL()
{
    // clear the buffer with the current clear color
    glClear(GL_COLOR_BUFFER_BIT);

    // draw a triangle with RGB color at the 3 vertices
    // interpolating smoothly the color in the interior
    GLdouble xA = (GLdouble)m_w / 3.0;
    GLdouble yA = (GLdouble)m_h / 3.0;
    GLdouble xB = (GLdouble)m_w * (2.0/3.0);
    GLdouble yB = (GLdouble)m_h / 3.0;
    GLdouble xC = (GLdouble)m_w / 2.0;
    GLdouble yC = (GLdouble)m_h * (2.0/3.0);
    glShadeModel(GL_SMOOTH);
    glBegin(GL_TRIANGLES);
    glColor3f(1.0, 0.0, 0.0);  // red
    glVertex2f(xA, yA);
    glColor3f(0.0, 1.0, 0.0); // green
    glVertex2f(xB, yB);
    glColor3f(0.0, 0.0, 1.0); // blue
    glVertex2f(xC, yC);
    glEnd();
}
